# DataJoint Element - Functional Calcium Imaging

DataJoint Element for functional calcium imaging with `ScanImage`, `Scanbox`,
`Nikon NIS`, or `PrairieView` acquisition software and `Suite2p`, `CaImAn`, and
`EXTRACT` analysis software. DataJoint Elements collectively standardize and automate
data collection and analysis for neuroscience experiments. Each Element is a modular
pipeline for data storage and processing with corresponding database tables that can be
combined with other Elements to assemble a fully functional pipeline.

![diagram](https://raw.githubusercontent.com/datajoint/element-calcium-imaging/main/images/diagram_flowchart.svg)

Installation and usage instructions can be found at the
[Element documentation](https://datajoint.com/docs/elements/element-calcium-imaging).
